==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/RoleBindingRestrictionSpecFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class RoleBindingRestrictionSpecFluent<A extends RoleBindingRestrictionSpecFluent<A>> extends BaseFluent<A>{
  public RoleBindingRestrictionSpecFluent() {
  }
  
  public RoleBindingRestrictionSpecFluent(RoleBindingRestrictionSpec instance) {
    this.copyInstance(instance);
  }
  private GroupRestrictionBuilder grouprestriction;
  private ServiceAccountRestrictionBuilder serviceaccountrestriction;
  private UserRestrictionBuilder userrestriction;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(RoleBindingRestrictionSpec instance) {
    instance = (instance != null ? instance : new RoleBindingRestrictionSpec());
  
    if (instance != null) {
        this.withGrouprestriction(instance.getGrouprestriction());
        this.withServiceaccountrestriction(instance.getServiceaccountrestriction());
        this.withUserrestriction(instance.getUserrestriction());
        this.withGrouprestriction(instance.getGrouprestriction());
        this.withServiceaccountrestriction(instance.getServiceaccountrestriction());
        this.withUserrestriction(instance.getUserrestriction());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public GroupRestriction buildGrouprestriction() {
    return this.grouprestriction!=null ?this.grouprestriction.build():null;
  }
  
  public A withGrouprestriction(GroupRestriction grouprestriction) {
    _visitables.get("grouprestriction").remove(this.grouprestriction);
    if (grouprestriction!=null){ this.grouprestriction= new GroupRestrictionBuilder(grouprestriction); _visitables.get("grouprestriction").add(this.grouprestriction);} else { this.grouprestriction = null; _visitables.get("grouprestriction").remove(this.grouprestriction); } return (A) this;
  }
  
  public boolean hasGrouprestriction() {
    return this.grouprestriction != null;
  }
  
  public GrouprestrictionNested<A> withNewGrouprestriction() {
    return new GrouprestrictionNested(null);
  }
  
  public GrouprestrictionNested<A> withNewGrouprestrictionLike(GroupRestriction item) {
    return new GrouprestrictionNested(item);
  }
  
  public GrouprestrictionNested<A> editGrouprestriction() {
    return withNewGrouprestrictionLike(java.util.Optional.ofNullable(buildGrouprestriction()).orElse(null));
  }
  
  public GrouprestrictionNested<A> editOrNewGrouprestriction() {
    return withNewGrouprestrictionLike(java.util.Optional.ofNullable(buildGrouprestriction()).orElse(new GroupRestrictionBuilder().build()));
  }
  
  public GrouprestrictionNested<A> editOrNewGrouprestrictionLike(GroupRestriction item) {
    return withNewGrouprestrictionLike(java.util.Optional.ofNullable(buildGrouprestriction()).orElse(item));
  }
  
  public ServiceAccountRestriction buildServiceaccountrestriction() {
    return this.serviceaccountrestriction!=null ?this.serviceaccountrestriction.build():null;
  }
  
  public A withServiceaccountrestriction(ServiceAccountRestriction serviceaccountrestriction) {
    _visitables.get("serviceaccountrestriction").remove(this.serviceaccountrestriction);
    if (serviceaccountrestriction!=null){ this.serviceaccountrestriction= new ServiceAccountRestrictionBuilder(serviceaccountrestriction); _visitables.get("serviceaccountrestriction").add(this.serviceaccountrestriction);} else { this.serviceaccountrestriction = null; _visitables.get("serviceaccountrestriction").remove(this.serviceaccountrestriction); } return (A) this;
  }
  
  public boolean hasServiceaccountrestriction() {
    return this.serviceaccountrestriction != null;
  }
  
  public ServiceaccountrestrictionNested<A> withNewServiceaccountrestriction() {
    return new ServiceaccountrestrictionNested(null);
  }
  
  public ServiceaccountrestrictionNested<A> withNewServiceaccountrestrictionLike(ServiceAccountRestriction item) {
    return new ServiceaccountrestrictionNested(item);
  }
  
  public ServiceaccountrestrictionNested<A> editServiceaccountrestriction() {
    return withNewServiceaccountrestrictionLike(java.util.Optional.ofNullable(buildServiceaccountrestriction()).orElse(null));
  }
  
  public ServiceaccountrestrictionNested<A> editOrNewServiceaccountrestriction() {
    return withNewServiceaccountrestrictionLike(java.util.Optional.ofNullable(buildServiceaccountrestriction()).orElse(new ServiceAccountRestrictionBuilder().build()));
  }
  
  public ServiceaccountrestrictionNested<A> editOrNewServiceaccountrestrictionLike(ServiceAccountRestriction item) {
    return withNewServiceaccountrestrictionLike(java.util.Optional.ofNullable(buildServiceaccountrestriction()).orElse(item));
  }
  
  public UserRestriction buildUserrestriction() {
    return this.userrestriction!=null ?this.userrestriction.build():null;
  }
  
  public A withUserrestriction(UserRestriction userrestriction) {
    _visitables.get("userrestriction").remove(this.userrestriction);
    if (userrestriction!=null){ this.userrestriction= new UserRestrictionBuilder(userrestriction); _visitables.get("userrestriction").add(this.userrestriction);} else { this.userrestriction = null; _visitables.get("userrestriction").remove(this.userrestriction); } return (A) this;
  }
  
  public boolean hasUserrestriction() {
    return this.userrestriction != null;
  }
  
  public UserrestrictionNested<A> withNewUserrestriction() {
    return new UserrestrictionNested(null);
  }
  
  public UserrestrictionNested<A> withNewUserrestrictionLike(UserRestriction item) {
    return new UserrestrictionNested(item);
  }
  
  public UserrestrictionNested<A> editUserrestriction() {
    return withNewUserrestrictionLike(java.util.Optional.ofNullable(buildUserrestriction()).orElse(null));
  }
  
  public UserrestrictionNested<A> editOrNewUserrestriction() {
    return withNewUserrestrictionLike(java.util.Optional.ofNullable(buildUserrestriction()).orElse(new UserRestrictionBuilder().build()));
  }
  
  public UserrestrictionNested<A> editOrNewUserrestrictionLike(UserRestriction item) {
    return withNewUserrestrictionLike(java.util.Optional.ofNullable(buildUserrestriction()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RoleBindingRestrictionSpecFluent that = (RoleBindingRestrictionSpecFluent) o;
    if (!java.util.Objects.equals(grouprestriction, that.grouprestriction)) return false;
  
    if (!java.util.Objects.equals(serviceaccountrestriction, that.serviceaccountrestriction)) return false;
  
    if (!java.util.Objects.equals(userrestriction, that.userrestriction)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(grouprestriction,  serviceaccountrestriction,  userrestriction,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (grouprestriction != null) { sb.append("grouprestriction:"); sb.append(grouprestriction + ","); }
    if (serviceaccountrestriction != null) { sb.append("serviceaccountrestriction:"); sb.append(serviceaccountrestriction + ","); }
    if (userrestriction != null) { sb.append("userrestriction:"); sb.append(userrestriction + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class GrouprestrictionNested<N> extends GroupRestrictionFluent<GrouprestrictionNested<N>> implements Nested<N>{
    GrouprestrictionNested(GroupRestriction item) {
      this.builder = new GroupRestrictionBuilder(this, item);
    }
    GroupRestrictionBuilder builder;
    
    public N and() {
      return (N) RoleBindingRestrictionSpecFluent.this.withGrouprestriction(builder.build());
    }
    
    public N endGrouprestriction() {
      return and();
    }
    
  
  }
  public class ServiceaccountrestrictionNested<N> extends ServiceAccountRestrictionFluent<ServiceaccountrestrictionNested<N>> implements Nested<N>{
    ServiceaccountrestrictionNested(ServiceAccountRestriction item) {
      this.builder = new ServiceAccountRestrictionBuilder(this, item);
    }
    ServiceAccountRestrictionBuilder builder;
    
    public N and() {
      return (N) RoleBindingRestrictionSpecFluent.this.withServiceaccountrestriction(builder.build());
    }
    
    public N endServiceaccountrestriction() {
      return and();
    }
    
  
  }
  public class UserrestrictionNested<N> extends UserRestrictionFluent<UserrestrictionNested<N>> implements Nested<N>{
    UserrestrictionNested(UserRestriction item) {
      this.builder = new UserRestrictionBuilder(this, item);
    }
    UserRestrictionBuilder builder;
    
    public N and() {
      return (N) RoleBindingRestrictionSpecFluent.this.withUserrestriction(builder.build());
    }
    
    public N endUserrestriction() {
      return and();
    }
    
  
  }

}

==> openshift-model-6.9.1-sources.jar: io/fabric8/openshift/api/model/RoleBindingRestrictionSpecFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class RoleBindingRestrictionSpecFluent<A extends RoleBindingRestrictionSpecFluent<A>> extends BaseFluent<A>{
  public RoleBindingRestrictionSpecFluent() {
  }
  
  public RoleBindingRestrictionSpecFluent(RoleBindingRestrictionSpec instance) {
    this.copyInstance(instance);
  }
  private GroupRestrictionBuilder grouprestriction;
  private ServiceAccountRestrictionBuilder serviceaccountrestriction;
  private UserRestrictionBuilder userrestriction;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(RoleBindingRestrictionSpec instance) {
    instance = (instance != null ? instance : new RoleBindingRestrictionSpec());
    if (instance != null) {
          this.withGrouprestriction(instance.getGrouprestriction());
          this.withServiceaccountrestriction(instance.getServiceaccountrestriction());
          this.withUserrestriction(instance.getUserrestriction());
          this.withGrouprestriction(instance.getGrouprestriction());
          this.withServiceaccountrestriction(instance.getServiceaccountrestriction());
          this.withUserrestriction(instance.getUserrestriction());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public GroupRestriction buildGrouprestriction() {
    return this.grouprestriction != null ? this.grouprestriction.build() : null;
  }
  
  public A withGrouprestriction(GroupRestriction grouprestriction) {
    this._visitables.remove(this.grouprestriction);
    if (grouprestriction != null) {
        this.grouprestriction = new GroupRestrictionBuilder(grouprestriction);
        this._visitables.get("grouprestriction").add(this.grouprestriction);
    } else {
        this.grouprestriction = null;
        this._visitables.get("grouprestriction").remove(this.grouprestriction);
    }
    return (A) this;
  }
  
  public boolean hasGrouprestriction() {
    return this.grouprestriction != null;
  }
  
  public GrouprestrictionNested<A> withNewGrouprestriction() {
    return new GrouprestrictionNested(null);
  }
  
  public GrouprestrictionNested<A> withNewGrouprestrictionLike(GroupRestriction item) {
    return new GrouprestrictionNested(item);
  }
  
  public GrouprestrictionNested<A> editGrouprestriction() {
    return withNewGrouprestrictionLike(java.util.Optional.ofNullable(buildGrouprestriction()).orElse(null));
  }
  
  public GrouprestrictionNested<A> editOrNewGrouprestriction() {
    return withNewGrouprestrictionLike(java.util.Optional.ofNullable(buildGrouprestriction()).orElse(new GroupRestrictionBuilder().build()));
  }
  
  public GrouprestrictionNested<A> editOrNewGrouprestrictionLike(GroupRestriction item) {
    return withNewGrouprestrictionLike(java.util.Optional.ofNullable(buildGrouprestriction()).orElse(item));
  }
  
  public ServiceAccountRestriction buildServiceaccountrestriction() {
    return this.serviceaccountrestriction != null ? this.serviceaccountrestriction.build() : null;
  }
  
  public A withServiceaccountrestriction(ServiceAccountRestriction serviceaccountrestriction) {
    this._visitables.remove(this.serviceaccountrestriction);
    if (serviceaccountrestriction != null) {
        this.serviceaccountrestriction = new ServiceAccountRestrictionBuilder(serviceaccountrestriction);
        this._visitables.get("serviceaccountrestriction").add(this.serviceaccountrestriction);
    } else {
        this.serviceaccountrestriction = null;
        this._visitables.get("serviceaccountrestriction").remove(this.serviceaccountrestriction);
    }
    return (A) this;
  }
  
  public boolean hasServiceaccountrestriction() {
    return this.serviceaccountrestriction != null;
  }
  
  public ServiceaccountrestrictionNested<A> withNewServiceaccountrestriction() {
    return new ServiceaccountrestrictionNested(null);
  }
  
  public ServiceaccountrestrictionNested<A> withNewServiceaccountrestrictionLike(ServiceAccountRestriction item) {
    return new ServiceaccountrestrictionNested(item);
  }
  
  public ServiceaccountrestrictionNested<A> editServiceaccountrestriction() {
    return withNewServiceaccountrestrictionLike(java.util.Optional.ofNullable(buildServiceaccountrestriction()).orElse(null));
  }
  
  public ServiceaccountrestrictionNested<A> editOrNewServiceaccountrestriction() {
    return withNewServiceaccountrestrictionLike(java.util.Optional.ofNullable(buildServiceaccountrestriction()).orElse(new ServiceAccountRestrictionBuilder().build()));
  }
  
  public ServiceaccountrestrictionNested<A> editOrNewServiceaccountrestrictionLike(ServiceAccountRestriction item) {
    return withNewServiceaccountrestrictionLike(java.util.Optional.ofNullable(buildServiceaccountrestriction()).orElse(item));
  }
  
  public UserRestriction buildUserrestriction() {
    return this.userrestriction != null ? this.userrestriction.build() : null;
  }
  
  public A withUserrestriction(UserRestriction userrestriction) {
    this._visitables.remove(this.userrestriction);
    if (userrestriction != null) {
        this.userrestriction = new UserRestrictionBuilder(userrestriction);
        this._visitables.get("userrestriction").add(this.userrestriction);
    } else {
        this.userrestriction = null;
        this._visitables.get("userrestriction").remove(this.userrestriction);
    }
    return (A) this;
  }
  
  public boolean hasUserrestriction() {
    return this.userrestriction != null;
  }
  
  public UserrestrictionNested<A> withNewUserrestriction() {
    return new UserrestrictionNested(null);
  }
  
  public UserrestrictionNested<A> withNewUserrestrictionLike(UserRestriction item) {
    return new UserrestrictionNested(item);
  }
  
  public UserrestrictionNested<A> editUserrestriction() {
    return withNewUserrestrictionLike(java.util.Optional.ofNullable(buildUserrestriction()).orElse(null));
  }
  
  public UserrestrictionNested<A> editOrNewUserrestriction() {
    return withNewUserrestrictionLike(java.util.Optional.ofNullable(buildUserrestriction()).orElse(new UserRestrictionBuilder().build()));
  }
  
  public UserrestrictionNested<A> editOrNewUserrestrictionLike(UserRestriction item) {
    return withNewUserrestrictionLike(java.util.Optional.ofNullable(buildUserrestriction()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RoleBindingRestrictionSpecFluent that = (RoleBindingRestrictionSpecFluent) o;
    if (!java.util.Objects.equals(grouprestriction, that.grouprestriction)) return false;
    if (!java.util.Objects.equals(serviceaccountrestriction, that.serviceaccountrestriction)) return false;
    if (!java.util.Objects.equals(userrestriction, that.userrestriction)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(grouprestriction,  serviceaccountrestriction,  userrestriction,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (grouprestriction != null) { sb.append("grouprestriction:"); sb.append(grouprestriction + ","); }
    if (serviceaccountrestriction != null) { sb.append("serviceaccountrestriction:"); sb.append(serviceaccountrestriction + ","); }
    if (userrestriction != null) { sb.append("userrestriction:"); sb.append(userrestriction + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class GrouprestrictionNested<N> extends GroupRestrictionFluent<GrouprestrictionNested<N>> implements Nested<N>{
    GrouprestrictionNested(GroupRestriction item) {
      this.builder = new GroupRestrictionBuilder(this, item);
    }
    GroupRestrictionBuilder builder;
    
    public N and() {
      return (N) RoleBindingRestrictionSpecFluent.this.withGrouprestriction(builder.build());
    }
    
    public N endGrouprestriction() {
      return and();
    }
    
  
  }
  public class ServiceaccountrestrictionNested<N> extends ServiceAccountRestrictionFluent<ServiceaccountrestrictionNested<N>> implements Nested<N>{
    ServiceaccountrestrictionNested(ServiceAccountRestriction item) {
      this.builder = new ServiceAccountRestrictionBuilder(this, item);
    }
    ServiceAccountRestrictionBuilder builder;
    
    public N and() {
      return (N) RoleBindingRestrictionSpecFluent.this.withServiceaccountrestriction(builder.build());
    }
    
    public N endServiceaccountrestriction() {
      return and();
    }
    
  
  }
  public class UserrestrictionNested<N> extends UserRestrictionFluent<UserrestrictionNested<N>> implements Nested<N>{
    UserrestrictionNested(UserRestriction item) {
      this.builder = new UserRestrictionBuilder(this, item);
    }
    UserRestrictionBuilder builder;
    
    public N and() {
      return (N) RoleBindingRestrictionSpecFluent.this.withUserrestriction(builder.build());
    }
    
    public N endUserrestriction() {
      return and();
    }
    
  
  }

}
